import { HTTP_INTERCEPTORS } from '@angular/common/http';
import { __read } from 'tslib';
import { ReplaySubject, merge, timer } from 'rxjs';
import { finalize, switchMap, debounce, distinctUntilChanged, tap, partition } from 'rxjs/operators';
import { DomSanitizer } from '@angular/platform-browser';
import { CommonModule } from '@angular/common';
import { Injectable, Component, NgModule, defineInjectable, inject, Input } from '@angular/core';

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var NgxHttpLoaderInterceptor = /** @class */ (function () {
    function NgxHttpLoaderInterceptor() {
        this.reqStatus$ = new ReplaySubject(1);
        this.pendingReqCnt = 0;
        this.forceStop = false;
        this.filterUrls = [];
        this.filterUrlPatterns = [];
        this.filterMethods = [];
        this.filterHeaders = [];
    }
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "pendingRequestCnt", {
        get: /**
         * @return {?}
         */
        function () {
            return this.pendingRequestCnt;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "reqStatus", {
        get: /**
         * @return {?}
         */
        function () {
            return this.reqStatus$.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "setFilterUrls", {
        set: /**
         * @param {?} urls
         * @return {?}
         */
        function (urls) {
            this.filterUrls = urls;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "setUrlPatterns", {
        set: /**
         * @param {?} regx
         * @return {?}
         */
        function (regx) {
            this.filterUrlPatterns = regx;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "setFilterMethods", {
        set: /**
         * @param {?} methods
         * @return {?}
         */
        function (methods) {
            this.filterMethods = methods;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "setFilterHeaders", {
        set: /**
         * @param {?} headers
         * @return {?}
         */
        function (headers) {
            this.filterHeaders = headers;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(NgxHttpLoaderInterceptor.prototype, "setForceStopReq", {
        set: /**
         * @param {?} bool
         * @return {?}
         */
        function (bool) {
            this.forceStop = bool;
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @param {?} url
     * @return {?}
     */
    NgxHttpLoaderInterceptor.prototype.checkIsFilterUrl = /**
     * @param {?} url
     * @return {?}
     */
    function (url) {
        return this.filterUrls.some(function (x) { return x === url; });
    };
    /**
     * @param {?} url
     * @return {?}
     */
    NgxHttpLoaderInterceptor.prototype.checkUrlPatterns = /**
     * @param {?} url
     * @return {?}
     */
    function (url) {
        return this.filterUrlPatterns.some(function (x) { return x.test(url); });
    };
    /**
     * @param {?} req
     * @return {?}
     */
    NgxHttpLoaderInterceptor.prototype.checkHttpMethod = /**
     * @param {?} req
     * @return {?}
     */
    function (req) {
        return this.filterMethods.some(function (e) {
            return e.toLowerCase() === req.method.toLowerCase();
        });
    };
    /**
     * @param {?} req
     * @return {?}
     */
    NgxHttpLoaderInterceptor.prototype.checkReqHeader = /**
     * @param {?} req
     * @return {?}
     */
    function (req) {
        return this.filterHeaders.some(function (e) {
            return req.headers.has(e);
        });
    };
    /**
     * @param {?} r
     * @return {?}
     */
    NgxHttpLoaderInterceptor.prototype.isStopReq = /**
     * @param {?} r
     * @return {?}
     */
    function (r) {
        return this.forceStop
            || this.checkIsFilterUrl(r.urlWithParams)
            || this.checkUrlPatterns(r.urlWithParams)
            || this.checkHttpMethod(r)
            || this.checkReqHeader(r);
    };
    /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    NgxHttpLoaderInterceptor.prototype.intercept = /**
     * @param {?} request
     * @param {?} next
     * @return {?}
     */
    function (request, next) {
        var _this = this;
        /** @type {?} */
        var isNext = this.isStopReq(request);
        if (!isNext) {
            this.pendingReqCnt++;
            if (1 === this.pendingReqCnt) {
                this.reqStatus$.next(true);
            }
        }
        return next.handle(request).pipe(finalize(function () {
            if (!isNext) {
                _this.pendingReqCnt--;
                if (0 === _this.pendingReqCnt) {
                    _this.reqStatus$.next(false);
                }
            }
        }));
    };
    NgxHttpLoaderInterceptor.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */ NgxHttpLoaderInterceptor.ngInjectableDef = defineInjectable({ factory: function NgxHttpLoaderInterceptor_Factory() { return new NgxHttpLoaderInterceptor(); }, token: NgxHttpLoaderInterceptor, providedIn: "root" });
    return NgxHttpLoaderInterceptor;
}());
/** @type {?} */
var RequestsInterceptorProvider = [{
        provide: HTTP_INTERCEPTORS,
        useExisting: NgxHttpLoaderInterceptor,
        multi: true
    }];

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var NgxHttpLoaderService = /** @class */ (function () {
    function NgxHttpLoaderService(reqService) {
        this.reqService = reqService;
        this.showLoader = new ReplaySubject(1);
    }
    Object.defineProperty(NgxHttpLoaderService.prototype, "isShowLoader", {
        get: /**
         * @return {?}
         */
        function () {
            return this.showLoader.asObservable();
        },
        enumerable: true,
        configurable: true
    });
    /**
     * @return {?}
     */
    NgxHttpLoaderService.prototype.show = /**
     * @return {?}
     */
    function () {
        this.reqService.setForceStopReq = true;
        this.showLoader.next(true);
    };
    /**
     * @return {?}
     */
    NgxHttpLoaderService.prototype.hide = /**
     * @return {?}
     */
    function () {
        this.showLoader.next(false);
        this.reqService.setForceStopReq = false;
    };
    NgxHttpLoaderService.decorators = [
        { type: Injectable, args: [{
                    providedIn: 'root'
                },] }
    ];
    /** @nocollapse */
    NgxHttpLoaderService.ctorParameters = function () { return [
        { type: NgxHttpLoaderInterceptor }
    ]; };
    /** @nocollapse */ NgxHttpLoaderService.ngInjectableDef = defineInjectable({ factory: function NgxHttpLoaderService_Factory() { return new NgxHttpLoaderService(inject(NgxHttpLoaderInterceptor)); }, token: NgxHttpLoaderService, providedIn: "root" });
    return NgxHttpLoaderService;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
/** @type {?} */
var NgxLoader = {
    DEFAULT: 'loader-default',
    CLOCK: 'loader-clock',
    DUALRING: 'loader-dual-ring',
    ELLIPSIS: 'loader-ellipsis',
    FACEBOOK: 'loader-facebook',
    GEAR: 'loader-gear',
    GRID: 'loader-grid',
    HEART: 'loader-heart',
    HOURGLASS: 'loader-hourglass',
    JELLYBOX: 'loader-jellybox',
    MULTICIRCLE: 'loader-multicicle',
    RING: 'loader-ring',
    RIPPLE: 'loader-ripple',
    ROLLER: 'loader-roller',
    SPINNER: 'loader-spinner',
    THREEBOUNCE: 'loader-three-bounce',
    WATERWAVE: 'loader-water-wave',
    ROTATINGPLANE: 'loader-rotating-plane',
};

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var NgxHttpLoaderComponent = /** @class */ (function () {
    function NgxHttpLoaderComponent(requestService, service, sanitizer) {
        this.requestService = requestService;
        this.service = service;
        this.sanitizer = sanitizer;
        this.customEnumLoader = NgxLoader;
        this.loader = NgxLoader.RIPPLE;
        this.filterUrlRegexPatterns = [];
        this.filterUrls = [];
        this.filterHttpHeaders = [];
        this.filterHttpMethods = [];
        this.delay = 0;
        this.extraDelay = 0;
        this.minDuration = 0;
        this.opacity = '.9';
        this.backdropBackgroundColor = 'linear-gradient(45deg, #222428, #444856)';
        this.iconColor = 'white';
        this.title = '';
        this.titleColor = '#fff';
        this.titleSize = '3rem';
        this.subTitle = '';
        this.subTitleColor = '#6c757d';
        this.subTitleSize = '1.2rem';
        this.custom = false;
        this.showuntil = Date.now();
    }
    /**
     * @param {?} changes
     * @return {?}
     */
    NgxHttpLoaderComponent.prototype.ngOnChanges = /**
     * @param {?} changes
     * @return {?}
     */
    function (changes) {
        if (this.filterUrlRegexPatterns.length > 0 || this.filterUrls.length > 0
            || this.filterHttpHeaders.length > 0 || this.filterHttpMethods.length > 0)
            this.initAllFilters();
    };
    /**
     * @return {?}
     */
    NgxHttpLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
        this.initAllFilters();
    };
    /**
     * @return {?}
     */
    NgxHttpLoaderComponent.prototype.initAllFilters = /**
     * @return {?}
     */
    function () {
        this.requestService.setUrlPatterns = this.filterUrlRegexPatterns;
        this.requestService.setFilterUrls = this.filterUrls;
        this.requestService.setFilterMethods = this.filterHttpMethods;
        this.requestService.setFilterHeaders = this.filterHttpHeaders;
        this.initShowObservable();
    };
    /**
     * @return {?}
     */
    NgxHttpLoaderComponent.prototype.initShowObservable = /**
     * @return {?}
     */
    function () {
        var _this = this;
        var _a = __read(partition(function ($hide) { return $hide; })(this.requestService.reqStatus), 2), show = _a[0], hide = _a[1];
        this.show$ = merge(this.requestService.reqStatus.pipe(switchMap(function () { return show.pipe(debounce(function () { return timer(_this.delay); })); })), show.pipe(switchMap(function () { return hide.pipe(debounce(function () { return _this.showUpto(); })); })), this.service.isShowLoader).pipe(distinctUntilChanged(), tap(function (x) { return _this.updateHideDelay(x); }));
    };
    /**
     * @param {?} bool
     * @return {?}
     */
    NgxHttpLoaderComponent.prototype.updateHideDelay = /**
     * @param {?} bool
     * @return {?}
     */
    function (bool) {
        if (bool)
            this.showuntil = Date.now() + this.minDuration;
    };
    /**
     * @return {?}
     */
    NgxHttpLoaderComponent.prototype.showUpto = /**
     * @return {?}
     */
    function () {
        return timer(Math.max(this.extraDelay, this.showuntil - Date.now()));
    };
    NgxHttpLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'ngx-http-loader',
                    template: "<div *ngIf=\"show$ | async\">\r\n    <ng-template [ngTemplateOutlet]=\"customTemplate || defaultTemplate\"></ng-template>\r\n    <ng-template #defaultTemplate>\r\n        <div class=\"custom-loader vertical-center\"\r\n            [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--background-color: ' + backdropBackgroundColor + '; opacity :' + opacity)\">\r\n            <div class=\"w-100 text-center text-light\"\r\n                [attr.style]=\"sanitizer.bypassSecurityTrustStyle('--iconcolor: ' + iconColor)\">\r\n                <ng-container *ngIf=\"custom\">\r\n                    <ng-template [ngTemplateOutlet]=\"customLoader\"></ng-template>\r\n                </ng-container>\r\n                <ng-container *ngIf=\"!custom\">\r\n                    <lib-gear-loader *ngIf=\"loader === customEnumLoader.GEAR\"></lib-gear-loader>\r\n                    <lib-grid-loader *ngIf=\"loader === customEnumLoader.GRID\"></lib-grid-loader>\r\n                    <lib-dual-ring-loader *ngIf=\"loader === customEnumLoader.DUALRING\"></lib-dual-ring-loader>\r\n                    <lib-clock-loader *ngIf=\"loader === customEnumLoader.CLOCK\"></lib-clock-loader>\r\n                    <lib-default-loader *ngIf=\"loader === customEnumLoader.DEFAULT\"></lib-default-loader>\r\n                    <lib-ellipsis-loader *ngIf=\"loader === customEnumLoader.ELLIPSIS\"></lib-ellipsis-loader>\r\n                    <lib-spinner-loader *ngIf=\"loader === customEnumLoader.SPINNER\"></lib-spinner-loader>\r\n                    <lib-facebook-loader *ngIf=\"loader === customEnumLoader.FACEBOOK\"></lib-facebook-loader>\r\n                    <lib-heart-loader *ngIf=\"loader === customEnumLoader.HEART\"></lib-heart-loader>\r\n                    <lib-hourglass-loader *ngIf=\"loader === customEnumLoader.HOURGLASS\"></lib-hourglass-loader>\r\n                    <lib-ring-loader *ngIf=\"loader === customEnumLoader.RING\"></lib-ring-loader>\r\n                    <lib-ripple-loader *ngIf=\"loader === customEnumLoader.RIPPLE\"></lib-ripple-loader>\r\n                    <lib-roller-loader *ngIf=\"loader === customEnumLoader.ROLLER\"></lib-roller-loader>\r\n                    <lib-water-wave-loader *ngIf=\"loader === customEnumLoader.WATERWAVE\"></lib-water-wave-loader>\r\n                    <lib-multicircle-loader *ngIf=\"loader === customEnumLoader.MULTICIRCLE\"></lib-multicircle-loader>\r\n                    <lib-three-bounce-loader *ngIf=\"loader === customEnumLoader.THREEBOUNCE\"></lib-three-bounce-loader>\r\n                    <lib-jellybox-loader *ngIf=\"loader === customEnumLoader.JELLYBOX\"></lib-jellybox-loader>\r\n                    <lib-rotating-plane *ngIf=\"loader === customEnumLoader.ROTATINGPLANE\"></lib-rotating-plane>\r\n                </ng-container>\r\n                <h1 *ngIf=\"title\" class=\"font-weight-bold text-shadow\"\r\n                    style=\"font-family:Trebuchet MS,Helvetica,sans-serif; width: 50%; margin: 10px auto; margin-top: 20px; word-break: break-all;\" \r\n                    [style.color]=\"titleColor\" [style.fontSize]=\"titleSize\">\r\n                    {{title}}\r\n                </h1>\r\n                <div style=\"width: 50%; margin: 10px auto; word-break: break-all;\" *ngIf=\"subTitle\" [style.color]=\"subTitleColor\" [style.fontSize]=\"subTitleSize\">{{subTitle}}</div>\r\n            </div>\r\n        </div>\r\n    </ng-template>\r\n</div>",
                    styles: [".custom-loader{position:fixed;top:0;left:0;width:100%;height:100%;background:var(--background-color);color:#fff;z-index:4000;transition:.3s linear}.custom-loader ::ng-deep>*{vertical-align:middle;white-space:normal;display:inline-block}.vertical-center:before{content:\"\";display:inline-block;vertical-align:middle;width:0;height:100%}"]
                }] }
    ];
    /** @nocollapse */
    NgxHttpLoaderComponent.ctorParameters = function () { return [
        { type: NgxHttpLoaderInterceptor },
        { type: NgxHttpLoaderService },
        { type: DomSanitizer }
    ]; };
    NgxHttpLoaderComponent.propDecorators = {
        customTemplate: [{ type: Input }],
        customLoader: [{ type: Input }],
        loader: [{ type: Input }],
        filterUrlRegexPatterns: [{ type: Input }],
        filterUrls: [{ type: Input }],
        filterHttpHeaders: [{ type: Input }],
        filterHttpMethods: [{ type: Input }],
        delay: [{ type: Input }],
        extraDelay: [{ type: Input }],
        minDuration: [{ type: Input }],
        opacity: [{ type: Input }],
        backdropBackgroundColor: [{ type: Input }],
        iconColor: [{ type: Input }],
        title: [{ type: Input }],
        titleColor: [{ type: Input }],
        titleSize: [{ type: Input }],
        subTitle: [{ type: Input }],
        subTitleColor: [{ type: Input }],
        subTitleSize: [{ type: Input }],
        custom: [{ type: Input }]
    };
    return NgxHttpLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var ClockLoaderComponent = /** @class */ (function () {
    function ClockLoaderComponent() {
    }
    /**
     * @return {?}
     */
    ClockLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    ClockLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-clock-loader',
                    template: "<div class=\"clock-loader\"></div>",
                    styles: [".clock-loader{--primary-color:var(--iconcolor);--clock-color:var(--primary-color);--clock-width:4rem;--clock-radius:calc(var(--clock-width) / 2);--clock-minute-length:calc(var(--clock-width) * 0.4);--clock-hour-length:calc(var(--clock-width) * 0.2);--clock-thickness:0.2rem;position:relative;display:flex;justify-content:center;align-items:center;width:var(--clock-width);height:var(--clock-width);border:3px solid var(--primary-color);border-radius:50%;margin:20px auto}.clock-loader::after,.clock-loader::before{position:absolute;content:\"\";top:calc(var(--clock-radius) * .25);width:var(--clock-thickness);background:var(--primary-color);border-radius:10px;transform-origin:center calc(100% - calc(var(--clock-thickness)/ 2));-webkit-animation:linear infinite spin;animation:linear infinite spin}.clock-loader::before{height:var(--clock-minute-length);-webkit-animation-duration:2s;animation-duration:2s}.clock-loader::after{top:calc(var(--clock-radius) * .25 + var(--clock-hour-length));height:var(--clock-hour-length);-webkit-animation-duration:15s;animation-duration:15s}@-webkit-keyframes spin{to{transform:rotate(1turn)}}@keyframes spin{to{transform:rotate(1turn)}}"]
                }] }
    ];
    /** @nocollapse */
    ClockLoaderComponent.ctorParameters = function () { return []; };
    return ClockLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var DefaultLoaderComponent = /** @class */ (function () {
    function DefaultLoaderComponent() {
    }
    /**
     * @return {?}
     */
    DefaultLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    DefaultLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-default-loader',
                    template: "<div class=\"lds-default\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                    styles: [".lds-default{display:inline-block;position:relative;width:80px;height:80px}.lds-default div{position:absolute;width:6px;height:6px;background:var(--iconcolor);border-radius:50%;-webkit-animation:1.2s linear infinite lds-default;animation:1.2s linear infinite lds-default}.lds-default div:nth-child(1){-webkit-animation-delay:0s;animation-delay:0s;top:37px;left:66px}.lds-default div:nth-child(2){-webkit-animation-delay:-.1s;animation-delay:-.1s;top:22px;left:62px}.lds-default div:nth-child(3){-webkit-animation-delay:-.2s;animation-delay:-.2s;top:11px;left:52px}.lds-default div:nth-child(4){-webkit-animation-delay:-.3s;animation-delay:-.3s;top:7px;left:37px}.lds-default div:nth-child(5){-webkit-animation-delay:-.4s;animation-delay:-.4s;top:11px;left:22px}.lds-default div:nth-child(6){-webkit-animation-delay:-.5s;animation-delay:-.5s;top:22px;left:11px}.lds-default div:nth-child(7){-webkit-animation-delay:-.6s;animation-delay:-.6s;top:37px;left:7px}.lds-default div:nth-child(8){-webkit-animation-delay:-.7s;animation-delay:-.7s;top:52px;left:11px}.lds-default div:nth-child(9){-webkit-animation-delay:-.8s;animation-delay:-.8s;top:62px;left:22px}.lds-default div:nth-child(10){-webkit-animation-delay:-.9s;animation-delay:-.9s;top:66px;left:37px}.lds-default div:nth-child(11){-webkit-animation-delay:-1s;animation-delay:-1s;top:62px;left:52px}.lds-default div:nth-child(12){-webkit-animation-delay:-1.1s;animation-delay:-1.1s;top:52px;left:62px}@-webkit-keyframes lds-default{0%,100%,20%,80%{transform:scale(1)}50%{transform:scale(1.5)}}@keyframes lds-default{0%,100%,20%,80%{transform:scale(1)}50%{transform:scale(1.5)}}"]
                }] }
    ];
    /** @nocollapse */
    DefaultLoaderComponent.ctorParameters = function () { return []; };
    return DefaultLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var DualRingLoaderComponent = /** @class */ (function () {
    function DualRingLoaderComponent() {
    }
    /**
     * @return {?}
     */
    DualRingLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    DualRingLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-dual-ring-loader',
                    template: "<div class=\"lds-dual-ring\"></div>",
                    styles: [".lds-dual-ring{display:inline-block;width:80px;height:80px}.lds-dual-ring:after{content:\" \";display:block;width:64px;height:64px;margin:8px;border-radius:50%;border:6px solid;border-color:var(--iconcolor) transparent var(--iconcolor) transparent;-webkit-animation:1.2s linear infinite lds-dual-ring;animation:1.2s linear infinite lds-dual-ring}@-webkit-keyframes lds-dual-ring{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes lds-dual-ring{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}"]
                }] }
    ];
    /** @nocollapse */
    DualRingLoaderComponent.ctorParameters = function () { return []; };
    return DualRingLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var EllipsisLoaderComponent = /** @class */ (function () {
    function EllipsisLoaderComponent() {
    }
    /**
     * @return {?}
     */
    EllipsisLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    EllipsisLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-ellipsis-loader',
                    template: "<div class=\"lds-ellipsis\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                    styles: [".lds-ellipsis{display:inline-block;position:relative;width:80px;height:80px}.lds-ellipsis div{position:absolute;top:33px;width:13px;height:13px;border-radius:50%;background:var(--iconcolor);-webkit-animation-timing-function:cubic-bezier(0,1,1,0);animation-timing-function:cubic-bezier(0,1,1,0)}.lds-ellipsis div:nth-child(1){left:8px;-webkit-animation:.6s infinite lds-ellipsis1;animation:.6s infinite lds-ellipsis1}.lds-ellipsis div:nth-child(2){left:8px;-webkit-animation:.6s infinite lds-ellipsis2;animation:.6s infinite lds-ellipsis2}.lds-ellipsis div:nth-child(3){left:32px;-webkit-animation:.6s infinite lds-ellipsis2;animation:.6s infinite lds-ellipsis2}.lds-ellipsis div:nth-child(4){left:56px;-webkit-animation:.6s infinite lds-ellipsis3;animation:.6s infinite lds-ellipsis3}@-webkit-keyframes lds-ellipsis1{0%{transform:scale(0)}100%{transform:scale(1)}}@keyframes lds-ellipsis1{0%{transform:scale(0)}100%{transform:scale(1)}}@-webkit-keyframes lds-ellipsis3{0%{transform:scale(1)}100%{transform:scale(0)}}@keyframes lds-ellipsis3{0%{transform:scale(1)}100%{transform:scale(0)}}@-webkit-keyframes lds-ellipsis2{0%{transform:translate(0,0)}100%{transform:translate(24px,0)}}@keyframes lds-ellipsis2{0%{transform:translate(0,0)}100%{transform:translate(24px,0)}}"]
                }] }
    ];
    /** @nocollapse */
    EllipsisLoaderComponent.ctorParameters = function () { return []; };
    return EllipsisLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var FacebookLoaderComponent = /** @class */ (function () {
    function FacebookLoaderComponent() {
    }
    /**
     * @return {?}
     */
    FacebookLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    FacebookLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-facebook-loader',
                    template: "<div class=\"lds-facebook\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                    styles: [".lds-facebook{display:inline-block;position:relative;width:80px;height:80px}.lds-facebook div{display:inline-block;position:absolute;left:8px;width:16px;background:var(--iconcolor);-webkit-animation:1.2s cubic-bezier(0,.5,.5,1) infinite lds-facebook;animation:1.2s cubic-bezier(0,.5,.5,1) infinite lds-facebook}.lds-facebook div:nth-child(1){left:8px;-webkit-animation-delay:-.24s;animation-delay:-.24s}.lds-facebook div:nth-child(2){left:32px;-webkit-animation-delay:-.12s;animation-delay:-.12s}.lds-facebook div:nth-child(3){left:56px;-webkit-animation-delay:0;animation-delay:0}@-webkit-keyframes lds-facebook{0%{top:8px;height:64px}100%,50%{top:24px;height:32px}}@keyframes lds-facebook{0%{top:8px;height:64px}100%,50%{top:24px;height:32px}}"]
                }] }
    ];
    /** @nocollapse */
    FacebookLoaderComponent.ctorParameters = function () { return []; };
    return FacebookLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var GearLoaderComponent = /** @class */ (function () {
    function GearLoaderComponent() {
    }
    /**
     * @return {?}
     */
    GearLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    GearLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-gear-loader',
                    template: "<svg class=\"gear\" style=\"width:64px\" xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <path id=\"p\"\n        d=\"M94.1 58.8c.6-2.8.9-5.8.9-8.8s-.3-6-.9-8.8l-11.7-.4c-.7-2.6-1.7-5-3-7.3l8-8.5c-3.3-4.9-7.5-9.2-12.5-12.5l-8.5 8c-2.3-1.3-4.7-2.3-7.3-3l-.3-11.6C56 5.3 53 5 50 5s-6 .3-8.8.9l-.4 11.7c-2.6.7-5 1.7-7.3 3l-8.5-8c-4.9 3.3-9.2 7.5-12.5 12.5l8 8.5c-1.3 2.3-2.3 4.7-3 7.3l-11.6.3C5.3 44 5 47 5 50s.3 6 .9 8.8l11.7.4c.7 2.6 1.7 5 3 7.3l-8 8.5c3.3 4.9 7.5 9.2 12.5 12.5l8.5-8c2.3 1.3 4.7 2.3 7.3 3l.4 11.7c2.7.5 5.7.8 8.7.8s6-.3 8.8-.9l.4-11.7c2.6-.7 5-1.7 7.3-3l8.5 8c4.9-3.3 9.2-7.5 12.5-12.5l-8-8.5c1.3-2.3 2.3-4.7 3-7.3l11.6-.3zM50 66.9c-9.3 0-16.9-7.6-16.9-16.9S40.7 33.1 50 33.1 66.9 40.7 66.9 50 59.3 66.9 50 66.9z\">\n    </path>\n</svg>\n<svg class=\"gear\" style=\"width:88px;margin:64px 0 0 -12px;animation-direction:reverse\"\n    xmlns=\"http://www.w3.org/2000/svg\" viewBox=\"0 0 100 100\">\n    <use href=\"#p\"></use>\n</svg>",
                    styles: ["@-webkit-keyframes r{0%{transform:rotate(0)}100%{transform:rotate(45deg)}}@keyframes r{0%{transform:rotate(0)}100%{transform:rotate(45deg)}}svg.gear{-webkit-animation:.5s linear infinite r;animation:.5s linear infinite r;fill:var(--iconcolor)}"]
                }] }
    ];
    /** @nocollapse */
    GearLoaderComponent.ctorParameters = function () { return []; };
    return GearLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var GridLoaderComponent = /** @class */ (function () {
    function GridLoaderComponent() {
    }
    /**
     * @return {?}
     */
    GridLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    GridLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-grid-loader',
                    template: "<div class=\"lds-grid\">\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n    <div></div>\n</div>",
                    styles: [".lds-grid{display:inline-block;position:relative;width:80px;height:80px}.lds-grid div{position:absolute;width:16px;height:16px;border-radius:50%;background:var(--iconcolor);-webkit-animation:1.2s linear infinite lds-grid;animation:1.2s linear infinite lds-grid}.lds-grid div:nth-child(1){top:8px;left:8px;-webkit-animation-delay:0s;animation-delay:0s}.lds-grid div:nth-child(2){top:8px;left:32px;-webkit-animation-delay:-.4s;animation-delay:-.4s}.lds-grid div:nth-child(3){top:8px;left:56px;-webkit-animation-delay:-.8s;animation-delay:-.8s}.lds-grid div:nth-child(4){top:32px;left:8px;-webkit-animation-delay:-.4s;animation-delay:-.4s}.lds-grid div:nth-child(5){top:32px;left:32px;-webkit-animation-delay:-.8s;animation-delay:-.8s}.lds-grid div:nth-child(6){top:32px;left:56px;-webkit-animation-delay:-1.2s;animation-delay:-1.2s}.lds-grid div:nth-child(7){top:56px;left:8px;-webkit-animation-delay:-.8s;animation-delay:-.8s}.lds-grid div:nth-child(8){top:56px;left:32px;-webkit-animation-delay:-1.2s;animation-delay:-1.2s}.lds-grid div:nth-child(9){top:56px;left:56px;-webkit-animation-delay:-1.6s;animation-delay:-1.6s}@-webkit-keyframes lds-grid{0%,100%{opacity:1}50%{opacity:.5}}@keyframes lds-grid{0%,100%{opacity:1}50%{opacity:.5}}"]
                }] }
    ];
    /** @nocollapse */
    GridLoaderComponent.ctorParameters = function () { return []; };
    return GridLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var HeartLoaderComponent = /** @class */ (function () {
    function HeartLoaderComponent() {
    }
    /**
     * @return {?}
     */
    HeartLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    HeartLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-heart-loader',
                    template: "<div class=\"lds-heart\">\r\n    <div></div>\r\n</div>",
                    styles: [".lds-heart{display:inline-block;position:relative;width:80px;height:80px;transform:rotate(45deg);transform-origin:40px 40px}.lds-heart div{top:32px;left:32px;position:absolute;width:32px;height:32px;background:var(--iconcolor);-webkit-animation:1.2s cubic-bezier(.215,.61,.355,1) infinite lds-heart;animation:1.2s cubic-bezier(.215,.61,.355,1) infinite lds-heart}.lds-heart div:after,.lds-heart div:before{content:\" \";position:absolute;display:block;width:32px;height:32px;background:var(--iconcolor)}.lds-heart div:before{left:-24px;border-radius:50% 0 0 50%}.lds-heart div:after{top:-24px;border-radius:50% 50% 0 0}@-webkit-keyframes lds-heart{0%,60%{transform:scale(.95)}5%{transform:scale(1.1)}39%{transform:scale(.85)}45%{transform:scale(1)}100%{transform:scale(.9)}}@keyframes lds-heart{0%,60%{transform:scale(.95)}5%{transform:scale(1.1)}39%{transform:scale(.85)}45%{transform:scale(1)}100%{transform:scale(.9)}}"]
                }] }
    ];
    /** @nocollapse */
    HeartLoaderComponent.ctorParameters = function () { return []; };
    return HeartLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var HourglassLoaderComponent = /** @class */ (function () {
    function HourglassLoaderComponent() {
    }
    /**
     * @return {?}
     */
    HourglassLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    HourglassLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-hourglass-loader',
                    template: "<div class=\"lds-hourglass\"></div>",
                    styles: [".lds-hourglass{display:inline-block;position:relative;width:80px;height:80px}.lds-hourglass:after{content:\" \";display:block;border-radius:50%;width:0;height:0;margin:8px;box-sizing:border-box;border:32px solid var(--iconcolor);border-color:var(--iconcolor) transparent var(--iconcolor) transparent;-webkit-animation:1.2s infinite lds-hourglass;animation:1.2s infinite lds-hourglass}@-webkit-keyframes lds-hourglass{0%{transform:rotate(0);-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19)}50%{transform:rotate(900deg);-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}100%{transform:rotate(1800deg)}}@keyframes lds-hourglass{0%{transform:rotate(0);-webkit-animation-timing-function:cubic-bezier(.55,.055,.675,.19);animation-timing-function:cubic-bezier(.55,.055,.675,.19)}50%{transform:rotate(900deg);-webkit-animation-timing-function:cubic-bezier(.215,.61,.355,1);animation-timing-function:cubic-bezier(.215,.61,.355,1)}100%{transform:rotate(1800deg)}}"]
                }] }
    ];
    /** @nocollapse */
    HourglassLoaderComponent.ctorParameters = function () { return []; };
    return HourglassLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var JellyboxLoaderComponent = /** @class */ (function () {
    function JellyboxLoaderComponent() {
    }
    /**
     * @return {?}
     */
    JellyboxLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    JellyboxLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-jellybox-loader',
                    template: "<div id=\"loader\">\n    <div id=\"box\"></div>\n    <div id=\"shadow\"></div>\n  </div>",
                    styles: ["@-webkit-keyframes loader{0%{left:-100px}100%{left:110%}}@keyframes loader{0%{left:-100px}100%{left:110%}}#box{width:70px;height:70px;background:var(--iconcolor);-webkit-animation:.5s linear infinite animate;animation:.5s linear infinite animate;border-radius:3px;margin:10px auto}@-webkit-keyframes animate{17%{border-bottom-right-radius:3px}25%{transform:translateY(9px) rotate(22.5deg)}50%{transform:translateY(18px) scale(1,.9) rotate(45deg);border-bottom-right-radius:40px}75%{transform:translateY(9px) rotate(67.5deg)}100%{transform:translateY(0) rotate(90deg)}}@keyframes animate{17%{border-bottom-right-radius:3px}25%{transform:translateY(9px) rotate(22.5deg)}50%{transform:translateY(18px) scale(1,.9) rotate(45deg);border-bottom-right-radius:40px}75%{transform:translateY(9px) rotate(67.5deg)}100%{transform:translateY(0) rotate(90deg)}}#shadow{width:80px;height:5px;background:#000;opacity:.1;border-radius:50%;-webkit-animation:.5s linear infinite shadow;animation:.5s linear infinite shadow;margin:0 auto}@-webkit-keyframes shadow{50%{transform:scale(1.2,1)}}@keyframes shadow{50%{transform:scale(1.2,1)}}"]
                }] }
    ];
    /** @nocollapse */
    JellyboxLoaderComponent.ctorParameters = function () { return []; };
    return JellyboxLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var MulticircleLoaderComponent = /** @class */ (function () {
    function MulticircleLoaderComponent() {
    }
    /**
     * @return {?}
     */
    MulticircleLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    MulticircleLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-multicircle-loader',
                    template: "<div id=\"loader\"></div>",
                    styles: ["#loader{display:block;position:relative;left:50%;top:50%;width:150px;height:150px;margin:-75px 0 0 -75px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);-webkit-animation:2s linear infinite spin;animation:2s linear infinite spin}#loader:before{content:\"\";position:absolute;top:5px;left:5px;right:5px;bottom:5px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);opacity:.2;-webkit-animation:3s linear infinite spin;animation:3s linear infinite spin}#loader:after{content:\"\";position:absolute;top:15px;left:15px;right:15px;bottom:15px;border-radius:50%;border:3px solid transparent;border-top-color:var(--iconcolor);opacity:.6;-webkit-animation:1.5s linear infinite spin;animation:1.5s linear infinite spin}@-webkit-keyframes spin{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes spin{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}"]
                }] }
    ];
    /** @nocollapse */
    MulticircleLoaderComponent.ctorParameters = function () { return []; };
    return MulticircleLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var RingLoaderComponent = /** @class */ (function () {
    function RingLoaderComponent() {
    }
    /**
     * @return {?}
     */
    RingLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    RingLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-ring-loader',
                    template: "<div class=\"lds-ring\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                    styles: [".lds-ring{display:inline-block;position:relative;width:80px;height:80px}.lds-ring div{box-sizing:border-box;display:block;position:absolute;width:64px;height:64px;margin:8px;border:8px solid;border-radius:50%;-webkit-animation:1.2s cubic-bezier(.5,0,.5,1) infinite lds-ring;animation:1.2s cubic-bezier(.5,0,.5,1) infinite lds-ring;border-color:var(--iconcolor) transparent transparent transparent}.lds-ring div:nth-child(1){-webkit-animation-delay:-.45s;animation-delay:-.45s}.lds-ring div:nth-child(2){-webkit-animation-delay:-.3s;animation-delay:-.3s}.lds-ring div:nth-child(3){-webkit-animation-delay:-.15s;animation-delay:-.15s}@-webkit-keyframes lds-ring{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes lds-ring{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}"]
                }] }
    ];
    /** @nocollapse */
    RingLoaderComponent.ctorParameters = function () { return []; };
    return RingLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var RippleLoaderComponent = /** @class */ (function () {
    function RippleLoaderComponent() {
    }
    /**
     * @return {?}
     */
    RippleLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    RippleLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-ripple-loader',
                    template: "<div class=\"lds-ripple\"><div></div><div></div></div>",
                    styles: [".lds-ripple{display:inline-block;position:relative;width:80px;height:80px}.lds-ripple div{position:absolute;border:4px solid var(--iconcolor);opacity:1;border-radius:50%;-webkit-animation:1s cubic-bezier(0,.2,.8,1) infinite lds-ripple;animation:1s cubic-bezier(0,.2,.8,1) infinite lds-ripple}.lds-ripple div:nth-child(2){-webkit-animation-delay:-.5s;animation-delay:-.5s}@-webkit-keyframes lds-ripple{0%{top:36px;left:36px;width:0;height:0;opacity:1}100%{top:0;left:0;width:72px;height:72px;opacity:0}}@keyframes lds-ripple{0%{top:36px;left:36px;width:0;height:0;opacity:1}100%{top:0;left:0;width:72px;height:72px;opacity:0}}"]
                }] }
    ];
    /** @nocollapse */
    RippleLoaderComponent.ctorParameters = function () { return []; };
    return RippleLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var RollerLoaderComponent = /** @class */ (function () {
    function RollerLoaderComponent() {
    }
    /**
     * @return {?}
     */
    RollerLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    RollerLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-roller-loader',
                    template: "<div class=\"lds-roller\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                    styles: [".lds-roller{display:inline-block;position:relative;width:80px;height:80px}.lds-roller div{-webkit-animation:1.2s cubic-bezier(.5,0,.5,1) infinite lds-roller;animation:1.2s cubic-bezier(.5,0,.5,1) infinite lds-roller;transform-origin:40px 40px}.lds-roller div:after{content:\" \";display:block;position:absolute;width:7px;height:7px;border-radius:50%;background:var(--iconcolor);margin:-4px 0 0 -4px}.lds-roller div:nth-child(1){-webkit-animation-delay:-36ms;animation-delay:-36ms}.lds-roller div:nth-child(1):after{top:63px;left:63px}.lds-roller div:nth-child(2){-webkit-animation-delay:-72ms;animation-delay:-72ms}.lds-roller div:nth-child(2):after{top:68px;left:56px}.lds-roller div:nth-child(3){-webkit-animation-delay:-108ms;animation-delay:-108ms}.lds-roller div:nth-child(3):after{top:71px;left:48px}.lds-roller div:nth-child(4){-webkit-animation-delay:-144ms;animation-delay:-144ms}.lds-roller div:nth-child(4):after{top:72px;left:40px}.lds-roller div:nth-child(5){-webkit-animation-delay:-.18s;animation-delay:-.18s}.lds-roller div:nth-child(5):after{top:71px;left:32px}.lds-roller div:nth-child(6){-webkit-animation-delay:-216ms;animation-delay:-216ms}.lds-roller div:nth-child(6):after{top:68px;left:24px}.lds-roller div:nth-child(7){-webkit-animation-delay:-252ms;animation-delay:-252ms}.lds-roller div:nth-child(7):after{top:63px;left:17px}.lds-roller div:nth-child(8){-webkit-animation-delay:-288ms;animation-delay:-288ms}.lds-roller div:nth-child(8):after{top:56px;left:12px}@-webkit-keyframes lds-roller{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes lds-roller{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}"]
                }] }
    ];
    /** @nocollapse */
    RollerLoaderComponent.ctorParameters = function () { return []; };
    return RollerLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var SpinnerLoaderComponent = /** @class */ (function () {
    function SpinnerLoaderComponent() {
    }
    /**
     * @return {?}
     */
    SpinnerLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    SpinnerLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-spinner-loader',
                    template: "<div class=\"lds-spinner\">\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n    <div></div>\r\n</div>",
                    styles: [".lds-spinner{color:official;display:inline-block;position:relative;width:80px;height:80px}.lds-spinner div{transform-origin:40px 40px;-webkit-animation:1.2s linear infinite lds-spinner;animation:1.2s linear infinite lds-spinner}.lds-spinner div:after{content:\" \";display:block;position:absolute;top:3px;left:37px;width:6px;height:18px;border-radius:20%;background:var(--iconcolor)}.lds-spinner div:nth-child(1){transform:rotate(0);-webkit-animation-delay:-1.1s;animation-delay:-1.1s}.lds-spinner div:nth-child(2){transform:rotate(30deg);-webkit-animation-delay:-1s;animation-delay:-1s}.lds-spinner div:nth-child(3){transform:rotate(60deg);-webkit-animation-delay:-.9s;animation-delay:-.9s}.lds-spinner div:nth-child(4){transform:rotate(90deg);-webkit-animation-delay:-.8s;animation-delay:-.8s}.lds-spinner div:nth-child(5){transform:rotate(120deg);-webkit-animation-delay:-.7s;animation-delay:-.7s}.lds-spinner div:nth-child(6){transform:rotate(150deg);-webkit-animation-delay:-.6s;animation-delay:-.6s}.lds-spinner div:nth-child(7){transform:rotate(180deg);-webkit-animation-delay:-.5s;animation-delay:-.5s}.lds-spinner div:nth-child(8){transform:rotate(210deg);-webkit-animation-delay:-.4s;animation-delay:-.4s}.lds-spinner div:nth-child(9){transform:rotate(240deg);-webkit-animation-delay:-.3s;animation-delay:-.3s}.lds-spinner div:nth-child(10){transform:rotate(270deg);-webkit-animation-delay:-.2s;animation-delay:-.2s}.lds-spinner div:nth-child(11){transform:rotate(300deg);-webkit-animation-delay:-.1s;animation-delay:-.1s}.lds-spinner div:nth-child(12){transform:rotate(330deg);-webkit-animation-delay:0s;animation-delay:0s}@-webkit-keyframes lds-spinner{0%{opacity:1}100%{opacity:0}}@keyframes lds-spinner{0%{opacity:1}100%{opacity:0}}"]
                }] }
    ];
    /** @nocollapse */
    SpinnerLoaderComponent.ctorParameters = function () { return []; };
    return SpinnerLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var ThreeBounceLoaderComponent = /** @class */ (function () {
    function ThreeBounceLoaderComponent() {
    }
    /**
     * @return {?}
     */
    ThreeBounceLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    ThreeBounceLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-three-bounce-loader',
                    template: "<div class=\"wrapper\">\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"circle\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n    <div class=\"shadow\"></div>\n</div>",
                    styles: [".wrapper{width:200px;height:60px;position:absolute;left:50%;top:40%;transform:translate(-50%,-50%)}.circle{width:20px;height:20px;position:absolute;border-radius:50%;background-color:var(--iconcolor);left:15%;transform-origin:50%;-webkit-animation:.5s infinite alternate circle;animation:.5s infinite alternate circle}@-webkit-keyframes circle{0%{top:60px;height:5px;border-radius:50px 50px 25px 25px;transform:scaleX(1.7)}40%{height:20px;border-radius:50%;transform:scaleX(1)}100%{top:0}}@keyframes circle{0%{top:60px;height:5px;border-radius:50px 50px 25px 25px;transform:scaleX(1.7)}40%{height:20px;border-radius:50%;transform:scaleX(1)}100%{top:0}}.circle:nth-child(2){left:45%;-webkit-animation-delay:.2s;animation-delay:.2s}.circle:nth-child(3){left:auto;right:15%;-webkit-animation-delay:.3s;animation-delay:.3s}.shadow{width:20px;height:4px;border-radius:50%;background-color:rgba(0,0,0,.5);position:absolute;top:62px;transform-origin:50%;z-index:-1;left:15%;filter:blur(1px);-webkit-animation:.5s infinite alternate shadow;animation:.5s infinite alternate shadow}@-webkit-keyframes shadow{0%{transform:scaleX(1.5)}40%{transform:scaleX(1);opacity:.7}100%{transform:scaleX(.2);opacity:.4}}@keyframes shadow{0%{transform:scaleX(1.5)}40%{transform:scaleX(1);opacity:.7}100%{transform:scaleX(.2);opacity:.4}}.shadow:nth-child(4){left:45%;-webkit-animation-delay:.2s;animation-delay:.2s}.shadow:nth-child(5){left:auto;right:15%;-webkit-animation-delay:.3s;animation-delay:.3s}.wrapper span{position:absolute;top:75px;font-family:Lato;font-size:20px;letter-spacing:12px;color:var(--iconcolor);left:15%}"]
                }] }
    ];
    /** @nocollapse */
    ThreeBounceLoaderComponent.ctorParameters = function () { return []; };
    return ThreeBounceLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var WaterWaveLoaderComponent = /** @class */ (function () {
    function WaterWaveLoaderComponent() {
    }
    /**
     * @return {?}
     */
    WaterWaveLoaderComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    WaterWaveLoaderComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-water-wave-loader',
                    template: "<div class=\"water\"></div>",
                    styles: [".water{width:100px;height:100px;background-color:var(--iconcolor);border-radius:50%;position:relative;box-shadow:inset 0 0 30px 0 rgba(0,0,0,.5),0 4px 10px 0 rgba(0,0,0,.5);overflow:hidden;margin:20px auto}.water:after,.water:before{content:'';position:absolute;width:400px;height:600px;top:-100px;background-color:#fff}.water:before{border-radius:45%;background:rgba(255,255,255,.7);-webkit-animation:5s linear infinite wave;animation:5s linear infinite wave}.water:after{border-radius:35%;background:rgba(255,255,255,.3);-webkit-animation:5s linear infinite wave;animation:5s linear infinite wave}@-webkit-keyframes wave{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}@keyframes wave{0%{transform:rotate(0)}100%{transform:rotate(360deg)}}"]
                }] }
    ];
    /** @nocollapse */
    WaterWaveLoaderComponent.ctorParameters = function () { return []; };
    return WaterWaveLoaderComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var RotatingPlaneComponent = /** @class */ (function () {
    function RotatingPlaneComponent() {
    }
    /**
     * @return {?}
     */
    RotatingPlaneComponent.prototype.ngOnInit = /**
     * @return {?}
     */
    function () {
    };
    RotatingPlaneComponent.decorators = [
        { type: Component, args: [{
                    selector: 'lib-rotating-plane',
                    template: "<div class=\"rotating-plane\"></div>",
                    styles: [".rotating-plane{width:50px;height:50px;background-color:var(--iconcolor);margin:0 auto;-webkit-animation:1.2s ease-in-out infinite rotateplane;animation:1.2s ease-in-out infinite rotateplane}@-webkit-keyframes rotateplane{0%{-webkit-transform:perspective(120px)}50%{-webkit-transform:perspective(120px) rotateY(180deg)}100%{-webkit-transform:perspective(120px) rotateY(180deg) rotateX(180deg)}}@keyframes rotateplane{0%{transform:perspective(120px) rotateX(0) rotateY(0);-webkit-transform:perspective(120px) rotateX(0) rotateY(0)}50%{transform:perspective(120px) rotateX(-180.1deg) rotateY(0);-webkit-transform:perspective(120px) rotateX(-180.1deg) rotateY(0)}100%{transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg);-webkit-transform:perspective(120px) rotateX(-180deg) rotateY(-179.9deg)}}"]
                }] }
    ];
    /** @nocollapse */
    RotatingPlaneComponent.ctorParameters = function () { return []; };
    return RotatingPlaneComponent;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */
var NgxHttpLoaderModule = /** @class */ (function () {
    function NgxHttpLoaderModule() {
    }
    /**
     * @return {?}
     */
    NgxHttpLoaderModule.forRoot = /**
     * @return {?}
     */
    function () {
        return {
            ngModule: NgxHttpLoaderModule,
            providers: [
                RequestsInterceptorProvider,
            ]
        };
    };
    NgxHttpLoaderModule.decorators = [
        { type: NgModule, args: [{
                    declarations: [
                        NgxHttpLoaderComponent,
                        GearLoaderComponent,
                        GridLoaderComponent,
                        DualRingLoaderComponent,
                        ClockLoaderComponent,
                        DefaultLoaderComponent,
                        EllipsisLoaderComponent,
                        FacebookLoaderComponent,
                        HeartLoaderComponent,
                        HourglassLoaderComponent,
                        RingLoaderComponent,
                        RippleLoaderComponent,
                        RollerLoaderComponent,
                        SpinnerLoaderComponent,
                        WaterWaveLoaderComponent,
                        ThreeBounceLoaderComponent,
                        MulticircleLoaderComponent,
                        JellyboxLoaderComponent,
                        RotatingPlaneComponent
                    ],
                    imports: [
                        CommonModule
                    ],
                    exports: [NgxHttpLoaderComponent]
                },] }
    ];
    return NgxHttpLoaderModule;
}());

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * @suppress {checkTypes,extraRequire,uselessCode} checked by tsc
 */

export { NgxHttpLoaderService, NgxHttpLoaderComponent, NgxHttpLoaderModule, NgxLoader, ClockLoaderComponent as ɵf, DefaultLoaderComponent as ɵg, DualRingLoaderComponent as ɵe, EllipsisLoaderComponent as ɵh, FacebookLoaderComponent as ɵi, GearLoaderComponent as ɵc, GridLoaderComponent as ɵd, HeartLoaderComponent as ɵj, HourglassLoaderComponent as ɵk, JellyboxLoaderComponent as ɵs, MulticircleLoaderComponent as ɵr, RingLoaderComponent as ɵl, RippleLoaderComponent as ɵm, RollerLoaderComponent as ɵn, RotatingPlaneComponent as ɵt, SpinnerLoaderComponent as ɵo, ThreeBounceLoaderComponent as ɵq, WaterWaveLoaderComponent as ɵp, NgxHttpLoaderInterceptor as ɵa, RequestsInterceptorProvider as ɵb };

//# sourceMappingURL=ngx-http-loader.js.map